@@ -283,32 +283,33 @@ class mCalendar:
                   self.db = sqlite3.connect(db_path)
                   self.dbcur = self.db.cursor()
 
-                try:                                  
-                  #quick fix
-                  self.dbcur.execute('CREATE TABLE cal (id TEXT PRIMARY KEY,access_level TEXT, color TEXT, last_update TEXT);')
-                  self.db.commit()
-                  self.dbcur.execute('ALTER TABLE events ADD cal_id TEXT')
-                  self.db.commit()
-                  self.dbcur.execute('CREATE TABLE cal (id TEXT PRIMARY KEY,access_level TEXT, color TEXT, last_update TEXT);')
-                  self.db.commit()
-                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("popup_alarm",?);',['False'])
-                  self.db.commit()
-                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("auto_sync",?);',['False'])
-                  self.db.commit()
-                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("use_google_color",?);',['True'])
-                  self.db.commit()
-                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("auto_sync_id",?);',[''])
-                  self.db.commit()
-                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("display_day",?);',['True'])
-                  self.db.commit()
-                except:
-                  pass
+#                try:                                  
+#                  #quick fix
+#                  self.dbcur.execute('CREATE TABLE cal (id TEXT PRIMARY KEY,access_level TEXT, color TEXT, last_update TEXT);')
+#                  self.db.commit()
+#                  self.dbcur.execute('ALTER TABLE events ADD cal_id TEXT')
+#                  self.db.commit()
+#                  self.dbcur.execute('CREATE TABLE cal (id TEXT PRIMARY KEY,access_level TEXT, color TEXT, last_update TEXT);')
+#                  self.db.commit()
+#                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("popup_alarm",?);',['False'])
+#                  self.db.commit()
+#                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("auto_sync",?);',['False'])
+#                  self.db.commit()
+#                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("use_google_color",?);',['True'])
+#                  self.db.commit()
+#                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("auto_sync_id",?);',[''])
+#                  self.db.commit()
+#                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("display_day",?);',['True'])
+#                  self.db.commit()
+#                except:
+#                  pass
 
                 try:
                   self.dbcur.execute('SELECT content FROM prefs WHERE id = "VERSION";')
                   v = self.dbcur.fetchall()
 
                   if len(v)==0:
+                    debug('Create the table for the first time')
                     self.createTable()
 
                   else:            
